.. image:: https://cognito.readthedocs.io/en/latest/_images/logo.png
    :target: http://cognito.readthedocs.org
    :width: 200pt

cognito : powerful data wrangling toolkit
==========================================


.. image:: https://travis-ci.org/CleverInsight/cognito.svg
   :target: https://travis-ci.org/CleverInsight/cognito

.. image:: https://coveralls.io/repos/CleverInsight/cognito/badge.png
   :target: https://coveralls.io/r/CleverInsight/cognito



.. |pypi| image:: https://img.shields.io/pypi/v/cognito.svg?logo=python&logoColor=white
  :target: https://pypi.org/project/cognito/

.. |conda| image:: https://img.shields.io/conda/vn/bastinrobin/cognito.svg?logo=conda-forge&logoColor=white
  :target: https://anaconda.org/bastinrobin/cognito

.. |travis| image:: https://travis-ci.org/CleverInsight/cognito.svg
  :target: https://travis-ci.org/CleverInsight/cognito

.. |coverall| image:: https://coveralls.io/repos/CleverInsight/cognito/badge.png
  :target: https://coveralls.io/r/CleverInsight/cognito

.. |contributors| image:: https://img.shields.io/github/contributors/Cleverinsight/cognito.svg?logo=github&logoColor=white
  :target: https://github.com/Cleverinsight/cognito/graphs/contributors/

.. |stars| image:: https://img.shields.io/github/stars/Cleverinsight/cognito.svg?style=social&label=Stars
  :target: https://github.com/Cleverinsight/cognito
  :alt: GitHub

.. |BSD| image:: https://img.shields.io/badge/License-BSD-yellow.svg
  :target: https://github.com/CleverInsight/cognito/blob/master/LICENSE

.. |IEEE| image:: https://img.shields.io/badge/License-BSD-yellow.svg
  :target: https://ieeexplore.ieee.org/document/9033938


.. |gitter| image:: https://img.shields.io/gitter/room/cognito-dev/community?color=darkviolet
  :target: https://gitter.im/cognito-dev/community


+----------------------+------------------------+
| Deployment           | |pypi| |conda|         |
+----------------------+------------------------+
| Build Status         | |travis|               |
+----------------------+------------------------+
| Metrics              | |coverall|             |
+----------------------+------------------------+
| GitHub               | |contributors| |stars| |
+----------------------+------------------------+
| License              | |BSD|                  |
+----------------------+------------------------+
| Community            | |gitter|               |
+----------------------+------------------------+


Cognito is an exclusive python data preprocessing library and command line utility that helps any developer to transform raw data into a machine-learning format. We at CleverInsight Open Ai Foundation took the initiative to build a better automated data preprocessing library and here it is.
  

Installation
------------

**Prerequisite**

- Python3.

Install the extension by using pip.

.. code:: bash

    $ pip install cognito



=======
Authors
=======

Core Lead
----------
* `Bastin Robins J <https://github.com/bastinrobin>`__ <robin@cleverinsight.co>

Development Leads
--------------------

* `Anshul Saxena <https://github.com/analyticsanshul>`__ <anshul.saxena@christuniversity.in>
* `Vandana Bhagat <https://github.com/vandana-11>`__ <vandana.bhagat@christuniversity.in>


Data Science Team
-----------------

* `Aastik <https://github.com/Aastik19>`__ <aastikkharbanda.ak@gmail.com>
* `Aishika <https://github.com/AishikaBanik98>`__ <aishikabanik98@gmail.com>
* `Nibir Paul <https://github.com/nibir-paul>`__ <nibirpaul491@gmail.com>
* `Rishika Kotta <https://github.com/RishikaKotta>`__ <rishikakotta21@gmail.com>
* `Tanvi Rath <https://github.com/tanvirath>`__ <rath.t98@gmail.com>

Collaborators 
==============

.. image:: https://github.com/CleverInsight/cognito/raw/master/docs/source/ystatic/christ_lavasa.jpg
   :width: 150pt
   :align: left
   :target: https://lavasa.christuniversity.in/

CHRIST (Deemed to be University) Lavasa <https://lavasa.christuniversity.in/>`_ provides developer & mentor contribution via CleverInsight Open AI Foundation Incubation Center at Christ Univeristy Lavasa since 2019.
   
